==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/model/query/ZdQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/18.
 */

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 宗地信息查询
 * @author shenjian
 * @version V1.0, 2014/8/18
 */

public class ZdQuery {
    private String djh;
    private String tdzh;
    private String qlrmc;
    private String tdzl;
    private String tdyt;
    private String tdytmc;
    private String qx;
    private String jd;
    private String jf;
    private BigDecimal scmjZd;
    private String zdlx;
    private String ids;
    private String excelBegin;
    private String excelEnd;
    private String gjzt;//宗地和供地的挂接状态 1，已经挂接，2，未挂接

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQx() {
        return qx;
    }

    public void setQx(String qx) {
        this.qx = qx;
    }

    public String getJd() {
        return jd;
    }

    public void setJd(String jd) {
        this.jd = jd;
    }

    public String getJf() {
        return jf;
    }

    public void setJf(String jf) {
        this.jf = jf;
    }

    public BigDecimal getScmjZd() {
        return scmjZd;
    }

    public void setScmjZd(BigDecimal scmjZd) {
        this.scmjZd = scmjZd;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getZdlx() {
        return zdlx;
    }

    public void setZdlx(String zdlx) {
        this.zdlx = zdlx;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getGjzt() {
        return gjzt;
    }

    public void setGjzt(String gjzt) {
        this.gjzt = gjzt;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/ZdQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/18.
 */

import java.math.BigDecimal;

/**
 * .
 * <p/>
 * 宗地信息查询
 * @author shenjian
 * @version V1.0, 2014/8/18
 */

public class ZdQuery {
    private String djh;
    private String tdzh;
    private String qlrmc;
    private String tdzl;
    private String tdzlzd;
    private String tdyt;
    private String tdytmc;
    private String qx;

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    private String jd;
    private String jf;
    private BigDecimal scmjZd;
    private String zdlx;
    private String ids;
    private String excelBegin;
    private String excelEnd;
    private String isqlrmc;//是否权利人名称为空
    private String mjceMin;//最小面积差额
    private String mjceMax;//最大面积差额
    public String getIsqlrmc() {
        return isqlrmc;
    }
    public void setIsqlrmc(String isqlrmc) {
        this.isqlrmc = isqlrmc;
    }

    public String getMjceMin() {
        return mjceMin;
    }
    public void setMjceMin(String mjceMin) {
        this.mjceMin = mjceMin;
    }

    public String getMjceMax() {
        return mjceMax;
    }
    public void setMjceMax(String mjceMax) {
        this.mjceMax = mjceMax;
    }


    private String gjzt;//宗地和供地的挂接状态 1，已经挂接，2，未挂接
    private String dwdm;
    private String tag;

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getTdzlzd() {
        return tdzlzd;
    }

    public void setTdzlzd(String tdzlzd) {
        this.tdzlzd = tdzlzd;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQx() {
        return qx;
    }

    public void setQx(String qx) {
        this.qx = qx;
    }

    public String getJd() {
        return jd;
    }

    public void setJd(String jd) {
        this.jd = jd;
    }

    public String getJf() {
        return jf;
    }

    public void setJf(String jf) {
        this.jf = jf;
    }

    public BigDecimal getScmjZd() {
        return scmjZd;
    }

    public void setScmjZd(BigDecimal scmjZd) {
        this.scmjZd = scmjZd;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getZdlx() {
        return zdlx;
    }

    public void setZdlx(String zdlx) {
        this.zdlx = zdlx;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getGjzt() {
        return gjzt;
    }

    public void setGjzt(String gjzt) {
        this.gjzt = gjzt;
    }
}
